===========
Quickstart
===========

Installation
--------------

Install from PyPI

.. code-block:: bash

    pip install rompy



or from source code

.. code-block:: bash

    git clone git@github.com:rom-py/rompy.git
    cd rompy
    pip install - e .

Usage
--------------


Simple example

.. code-block:: python

    from rompy import ModelRun

    # Initiate a model run
    run = ModelRun()

    # Execute the model run
    run()

  
